# coding=utf-8
# pylint: disable=import-error,eval-used
import json
from resources.models.helper import rest_get_call
from resources.models.helper import rest_post_json_call
from resources.models.helper import rest_delete_call
from resources.models.helper import State
from resources.test_db_resource import TestDBResource


class StopFlagResource(object):

    def __init__(self, host, port, session, time_out):
        self.host = host
        self.port = port
        self.session = session
        self.time_out = time_out

    def get_stop_flag(self):
        url_ = "http://{0}:{1}/stopflag".format(self.host, self.port)
        result = rest_get_call(url_, self.session, self.time_out)
        if result["resource"]["state"] == State.PASS:
            result["resource"]["data"] = eval(result["resource"]["data"][0])
        return result["resource"]

    def set_stop_flag(self, stop_flag):
        data = {"stop_flag": stop_flag}
        url_ = "http://{0}:{1}/stopflag".format(self.host, self.port)
        result = rest_post_json_call(url_, self.session, json.dumps(data), self.time_out)
        return result["resource"]


# coding=utf-8
# pylint: disable=import-error, broad-except
import json
from resources.models.helper import rest_post_json_call
from resources.models.helper import rest_get_call


class OakgateResource(object):

    def __init__(self, host, port, session, time_out):
        self.host = host
        self.port = port
        self.session = session
        self.time_out = time_out

    def get_oakgate_device_list(self):
        url_ = "http://{0}:{1}/oakgate/device_list".format(self.host, self.port)
        result = rest_get_call(url_, self.session, self.time_out)
        return result["resource"]




# coding=utf-8
# pylint: disable=broad-except, import-error
import pymysql as mysql
from DBUtils.PooledDB import PooledDB


class SqlConnection(object):

    pool = dict()

    def __init__(self, host="172.29.129.8", port=3306, user="tester", passwd="Cnex!321", db_name="production_test"):
        self.host = host
        self.port = port
        self.user = user
        self.passwd = passwd
        self.db_name = db_name
        self.conn = self.__get_conn()
        self.cursor = self.conn.cursor()

    def __get_conn(self):
        if self.db_name not in SqlConnection.pool.keys():
            SqlConnection.pool[self.db_name] =  PooledDB(creator=mysql, mincached=1 , maxcached=20 ,
                                                         host=self.host , port=self.port, user=self.user,
                                                         passwd=self.passwd, db=self.db_name,
                                                         use_unicode=True,charset="utf8")
        return SqlConnection.pool[self.db_name].connection()

    def __del__(self):
        self.cursor.close()
        self.conn.close()

    def execute_sql_command(self, command):
        results = list()
        try:
            self.conn.ping()
            self.cursor.execute(command)
            results = self.cursor.fetchall()
        except BaseException as message:
            print(message)
        return results

    def execute_and_commit_sql_command(self, command):
        results = list()
        try:
            self.conn.ping()
            self.cursor.execute(command)
            self.conn.commit()
            results = self.cursor.fetchall()
        except BaseException as message:
            print(message)
        return results

    def insert_to_table(self, table, fields):
        col_str = ""
        value_str = ""
        for key, value in fields.items():
            if value is False:
                value = "0"
            if value is True:
                value = "1"
            col_str = "`{}`".format(key) if col_str == "" else "{},`{}`".format(col_str, key)
            value_str = "'{}'".format(value) if value_str == "" else "{},'{}'".format(value_str, value)
        insert_command = "INSERT INTO {} ({}) VALUES({})".format(table, col_str, value_str)
        self.cursor.execute(insert_command)
        self.conn.commit()


if __name__ == '__main__':
    import json
    db = SqlConnection(db_name="web_testing")
    with open(r"E:\web\parameters.json", 'r') as load_f:
        load_dict = json.load(load_f)
        for item in load_dict:
            db.insert_to_table("test_platform_parameterconfig", item["fields"])
        pass

    pass


import json
from resources.models.helper import rest_post_json_call


class UpgradeResource(object):

    def __init__(self, host, port, session, time_out):
        self.host = host
        self.port = port
        self.session = session
        self.time_out = time_out

    def run(self, execute_name, parameters):
        data = {"execute_name": execute_name, "parameters":parameters}
        url_ = "http://{0}:{1}/upgrade".format(self.host, self.port)
        result = rest_post_json_call(url_, self.session, json.dumps(data), self.time_out)
        return result["resource"]




import datetime
from resources.models.database import SqlConnection


class Cleaner(object):

    def __init__(self):
        self.sql = SqlConnection(db_name="performance_test")

    def get_all_tests(self):
        command_line = "SELECT * FROM _tests"
        tests = self.sql.execute_sql_command(command_line)
        return tests

    def filter_not_confirmed_finished_tests(self, tests):
        current_time = datetime.datetime.now()
        filter_tests = list()
        for test in tests:
            if test[15] == 0 and test[13] !=1:
                start_time = test[11]
                distance = current_time - start_time
                if distance.days > 15:
                    filter_tests.append(test)
        return filter_tests

    def delete_table(self, table):
        command_line = "DROP TABLE {}".format(table)
        self.sql.execute_and_commit_sql_command(command_line)

    def delete_row(self, index):
        command_line = "DELETE FROM _tests WHERE `index`={}".format(index)
        self.sql.execute_and_commit_sql_command(command_line)

    def delete_tests(self, tests):
        for test in tests:
            self.delete_table(test[6])
            self.delete_row(test[0])

    def get_tests(self, group_key):
        command_line = "SELECT * FROM _tests WHERE `group_key`='{}'".format(group_key)
        tests = self.sql.execute_sql_command(command_line)
        return tests

    def delete_test_group(self, group_key):
        tests = self.get_tests(group_key)
        self.delete_tests(tests)


if __name__ == '__main__':
    CL = Cleaner()
    CL.delete_test_group("20191024152701_bPHZGu8tCv")

